@@ -1,17 +1,31 @@
 # Copyright 2012-2013, Andrey Kislyuk and argcomplete contributors.
 # Licensed under the Apache License. See https://github.com/kislyuk/argcomplete for more info.
 
+# Copy of __expand_tilde_by_ref from bash-completion
+__python_argcomplete_expand_tilde_by_ref () {
+    if [ "${!1:0:1}" = "~" ]; then
+        if [ "${!1}" != "${!1//\/}" ]; then
+            eval $1="${!1/%\/*}"/'${!1#*/}';
+        else
+            eval $1="${!1}";
+        fi;
+    fi
+}
+
 _python_argcomplete_global() {
+    local executable=$1
+    __python_argcomplete_expand_tilde_by_ref executable
+
     local ARGCOMPLETE=0
-    if [[ "$1" == python* ]] || [[ "$1" == pypy* ]]; then
+    if [[ "$executable" == python* ]] || [[ "$executable" == pypy* ]]; then
         if [[ -f "${COMP_WORDS[1]}" ]] && (head -c 1024 "${COMP_WORDS[1]}" | grep --quiet "PYTHON_ARGCOMPLETE_OK") >/dev/null 2>&1; then
             local ARGCOMPLETE=2
             set -- "${COMP_WORDS[1]}"
         fi
-    elif which "$1" >/dev/null 2>&1; then
-        local SCRIPT_NAME=$(which "$1")
+    elif which "$executable" >/dev/null 2>&1; then
+        local SCRIPT_NAME=$(which "$executable")
         if (type -t pyenv && [[ "$SCRIPT_NAME" = $(pyenv root)/shims/* ]]) >/dev/null 2>&1; then
-            local SCRIPT_NAME=$(pyenv which "$1")
+            local SCRIPT_NAME=$(pyenv which "$executable")
         fi
         if (head -c 1024 "$SCRIPT_NAME" | grep --quiet "PYTHON_ARGCOMPLETE_OK") >/dev/null 2>&1; then
             local ARGCOMPLETE=1
@@ -28,7 +42,7 @@ _python_argcomplete_global() {
             COMP_POINT="$COMP_POINT" \
             _ARGCOMPLETE_COMP_WORDBREAKS="$COMP_WORDBREAKS" \
             _ARGCOMPLETE=$ARGCOMPLETE \
-            "$1" 8>&1 9>&2 1>/dev/null 2>&1) )
+            "$executable" 8>&1 9>&2 1>/dev/null 2>&1) )
         if [[ $? != 0 ]]; then
             unset COMPREPLY
         fi
